Target Lists
============

Target lists are a way for you to group your ``Targets`` together. This can be for any number of purposes, including
creating an observing list, grouping similar targets for further analysis, or simply for organizational purposes.

You can group ``Targets`` through the API or from the 'Target Groupings' page in the TOM.

.. automodule:: tom_targets.groups
    :members: